import React, { useMemo } from 'react'
import { View, Text, TouchableWithoutFeedback } from 'react-native'

import { NavigationContainer } from '@react-navigation/native'
import {
  createStackNavigator,
  StackNavigationOptions,
} from '@react-navigation/stack'

import { translate } from '~/lib/i18n/i18n'
import RouteConfigStyle from '~/routes/RouteConfig.style'
import { TRouteConfig, TRoutes } from '~/routes/RoutesConfig.types'
import { RoutesConfigNavigationRef } from '~/routes/RoutesConfigNavigationRef'
import { InvoiceScreen } from '~/screens/Invoice/InvoiceScreen'
import { ModalScreen } from '~/screens/Modal/ModalScreen'

const { Screen, Navigator, Group } = createStackNavigator<TRoutes>()

const SCREENS: TRouteConfig[] = [
  {
    component: InvoiceScreen,
    name: 'Invoice',
    options: {
      title: translate('invoice'),
    },
  },
]

export const MODALS: TRouteConfig[] = [
  {
    name: 'Modal',
    component: ModalScreen,
    options: { title: translate('modal.title') },
  },
]

export const RoutesConfig: React.FC = () => {
  const style = RouteConfigStyle()

  const modalOptions = useMemo<StackNavigationOptions>(
    () => ({
      presentation: 'modal',
      header: ({ navigation: { goBack } }) => (
        <View style={style.routesConfig__modalHeader}>
          <TouchableWithoutFeedback onPress={() => goBack()}>
            <Text>{translate('modal.close_button')}</Text>
          </TouchableWithoutFeedback>
        </View>
      ),
    }),
    [style],
  )

  return (
    <NavigationContainer ref={RoutesConfigNavigationRef}>
      <Navigator initialRouteName="Invoice">
        <Group>
          {SCREENS.map(route => (
            <Screen {...route} key={route.name} />
          ))}
        </Group>

        <Group screenOptions={modalOptions}>
          {MODALS.map(modal => (
            <Screen {...modal} key={modal.name} />
          ))}
        </Group>
      </Navigator>
    </NavigationContainer>
  )
}
