import React from 'react'
import { View, Text, FlatList, TouchableWithoutFeedback } from 'react-native'
import { useSelector } from 'react-redux'

import { translate } from '~/lib/i18n/i18n'
import InvoiceScreenStyles from '~/screens/Invoice/InvoiceScreen.style'
import { TInvoiceScreenProps } from '~/screens/Invoice/InvoiceScreen.types'
import { selectInvoicesCustomer } from '~/store/Invoice/InvoiceSelectors'

export const InvoiceScreen: React.FC<TInvoiceScreenProps> = props => {
  const {
    navigation: { navigate },
  } = props
  const customers = useSelector(selectInvoicesCustomer)
  const styles = InvoiceScreenStyles(props)

  return (
    <View style={styles.invoiceScreen__onboardingView}>
      <Text>{translate('default')}</Text>
      <FlatList
        data={customers}
        renderItem={({ item }) => <Text>{item.invoiceNumber}</Text>}
        keyExtractor={item => item.customerCode}
      />
      <TouchableWithoutFeedback onPress={() => navigate('Modal')}>
        <Text>{translate('modal.title')}</Text>
      </TouchableWithoutFeedback>
    </View>
  )
}
