import produce from 'immer'
import { Reducer } from 'redux'

import { IInvoice } from '~/@types/entities/InvoiceEntity.types'
import {
  EInvoiceActionTypes,
  IInvoiceState,
} from '~/store/Invoice/InvoiceCreators.types'

export const INVOICE_INITIAL_STATE: IInvoiceState = {}

export const InvoiceReducer: Reducer<IInvoiceState> = (
  state = INVOICE_INITIAL_STATE,
  action,
) =>
  produce(state, draft => {
    switch (action.type) {
      case EInvoiceActionTypes.INVOICE_ISSUE_TARGET: {
        return draft
      }

      case EInvoiceActionTypes.INVOICE_CREATE_INVOICE: {
        const {
          payload: { invoice },
        } = action as ReturnType<typeof invoiceCreateInvoice>

        draft.saleInvoices.push(invoice)

        return draft
      }

      default: {
        return draft
      }
    }
  })

export const invoiceIssueTarget = () => ({
  type: EInvoiceActionTypes.INVOICE_ISSUE_TARGET,
})

export const invoiceCreateInvoice = (invoice: IInvoice) => ({
  type: EInvoiceActionTypes.INVOICE_CREATE_INVOICE,
  payload: { invoice },
})
