import AsyncStorage from '@react-native-async-storage/async-storage'
import { applyMiddleware, combineReducers, createStore, Store } from 'redux'
import { persistReducer, persistStore } from 'redux-persist'
import createSagaMiddleware from 'redux-saga'

import { InvoiceReducer } from '~/store/Invoice/InvoiceCreators'
import { SagaConfig } from '~/store/SagaConfig'
import { TStoreState } from '~/store/StoreConfig.types'

const PERSIST_CONFIG = {
  key: 'root',
  storage: AsyncStorage,
}

const ReducerConfig = combineReducers({
  invoice: InvoiceReducer,
})

export const PersistedReducer = persistReducer(PERSIST_CONFIG, ReducerConfig)
export const SagaMiddleware = createSagaMiddleware()

const middlewares = [SagaMiddleware]

if (__DEV__ && !process.env.JEST_WORKER_ID) {
  const createDebugger = require('redux-flipper').default
  middlewares.push(createDebugger())
}

const store: Store<TStoreState> = createStore(
  PersistedReducer,
  applyMiddleware(...middlewares),
)

SagaMiddleware.run(SagaConfig)

export default () => {
  let persistor = persistStore(store)
  return { store, persistor }
}
